<?php
/**
 * Created by PhpStorm.
 * User: gabi
 * Date: 23/05/2019
 * Time: 12:21
 */

namespace Buddycore;


class Shortcodes {

	public function __construct() {
		add_action( 'init', [ $this, 'init' ], 8 );
		add_action( 'wp', [ $this, 'check_page_template' ] );
	}

	public function init() {
		if ( class_exists( 'kleo_search_form' ) ) {
			add_shortcode( 'kleo_search_form', 'kleo_search_form' );
		}

		/* Small shortcode to style elements */
		add_shortcode( 'kleo_dashboard', [ $this, 'dashboard' ] );

		/* Theme specific login form */
		if ( function_exists( 'kleo_get_template_part' ) ) {
			add_shortcode( 'sq_login_form', [ $this, 'login_form' ] );
		}

		add_shortcode( 'current-year', [ $this, 'current_year' ] );

	}

	/**
	 * Return Year for current-year shortcode
	 *
	 * @param $atts
	 * @param null $content
	 *
	 * @return false|string
	 */
	public function current_year( $atts, $content = null ) {
		return date( 'Y' );
	}

	/**
	 * Check if we have login shortcode so we can redirect to home
	 * Remove admin bar and footer on blank template
	 */
	public function check_page_template() {
		if ( ! function_exists( 'kleo_has_shortcode' ) ) {
			return;
		}

		if ( kleo_has_shortcode( 'sq_login_form' ) && is_user_logged_in() && ! is_admin() && ! is_home() ) {
			wp_redirect( home_url() );
			exit;
		}

		if ( is_page_template( 'page-templates/blank.php' ) ) {
			/* remove admin bar */
			remove_action( 'wp_footer', 'wp_admin_bar_render', 1000 );
			add_filter( 'show_admin_bar', '__return_false' );
		}
	}

	/**
	 * Return login form for shortcode
	 *
	 * @param $atts
	 * @param null $content
	 *
	 * @return string
	 */
	public function login_form( $atts, $content = null ) {

		$output = $style = $disable_modal = '';

		extract( shortcode_atts( array(
			'style'         => 'white',
			'before_input'  => '',
			'disable_modal' => ''
		), $atts ) );

		$output .= '<div class="login-page-wrap">';
		/*if ( is_super_admin() ) {
			$output .= '<p style="text-align: center; max-width: 800px; padding: 20px; background: #fafafa;margin: 0 auto;">' .
			           'You are logged in as super admin! Regular logged in users will get redirected as in WP admin - Appearance - Theme options - Login redirect' .
			           '<br>' . wp_kses_post( sprintf( __( '<a href="%s">Go Home</a>', 'buddyapp' ), esc_url( home_url( '/' ) ) ) ) .
			           '</p>';
		}*/


		ob_start();
		kleo_get_template_part( 'page-parts/login-form', null, compact( 'style', 'before_input' ) );
		$output .= ob_get_clean();
		$output .= '</div>';

		if ( $disable_modal == '' ) {
			add_filter( "get_template_part_page-parts/login-form", '__return_false' );
		}

		return $output;
	}


	public function dashboard( $atts, $content = null ) {
		$output = $title = $title_stroke = $el_class = '';
		extract( shortcode_atts( array(
			'title'        => '',
			'title_stroke' => 'yes',
			'el_class'     => ''
		), $atts ) );


		$classes = '';

		if ( $el_class != '' ) {
			$classes .= ' ' . $el_class;
		}

		if ( $title_stroke == 'yes' ) {
			$classes .= ' has-title-stroke';
		}

		$output .= '<div class="dashboard-container' . $classes . '">';

		if ( $title != '' ) {
			$output .= '<div class="dashboard-title">' . $title . '</div>';
		}
		$output .= '<div class="dashboard-content">';
		$output .= do_shortcode( $content );
		$output .= '</div>';

		$output .= '</div>';

		return $output;

	}
}
