<?php
/**
 * @package WordPress
 * @subpackage Next
 * @author SeventhQueen <themesupport@seventhqueen.com>
 * @since Next 1.0
 */

/***************************************************
 * :: Load Kleo framework
 ***************************************************/

define( 'KLEO_THEME_VERSION', '1.9.1' );

if ( ! isset( $content_width ) ) {
	$content_width = 1200;
}

require_once( trailingslashit( get_template_directory() ) . 'kleo-framework/kleo.php' );

//set some theme configuration options
Kleo::init_config( array(
	'styling_variables'       => array(
		'background-color' => esc_html__( 'Background color', 'buddyapp' ),
		'border-color'     => esc_html__( 'Border color', 'buddyapp' ),
		'heading-color'    => esc_html__( 'Heading color', 'buddyapp' ),
		'text-color'       => esc_html__( 'Text color', 'buddyapp' ),
		'link-color'       => esc_html__( 'Link color', 'buddyapp' ),
		'hover-link-color' => esc_html__( 'Hover Link color', 'buddyapp' ),
		'accent-color'     => esc_html__( 'Accent color', 'buddyapp' )
	),
	//Post image sizes for carousels and galleries
	'post_gallery_img_width'  => 600,
	'post_gallery_img_height' => 400,

	//page templates
	'tpl_map'                 => array(
		'page-templates/full-width.php'    => 'full',
		'page-templates/left-sidebar.php'  => 'left',
		'page-templates/right_sidebar.php' => 'right',
	),
	'container_class'         => 'container-fluid',
	'menu_icon_default'       => 'buddyapp-default',
	'footer_text'             => 'Proudly powered by WordPress. Developed by <a target="_blank" href="http://7thqueen.com">SeventhQueen</a>',
	'default_font_headings'   => 'Montserrat',
	'default_font_text'       => 'Open Sans',
	'blog_meta_defaults'      => array( 'date', 'author_link', 'categories', 'tags', 'comments' ),
	'blog_meta_elements'      => array(
		'avatar'      => 'Author Avatar',
		'author_link' => 'Author name',
		'date'        => 'Date',
		'message'     => 'Message Link',
		'categories'  => 'Categories',
		'tags'        => 'Tags',
		'comments'    => 'Comments'
	)

) );


/***************************************************
 * :: Theme Required plugins
 ***************************************************/
require_once get_template_directory() . '/lib/required-plugins.php';


/**
 * Sets up theme defaults and registers the various WordPress features
 *
 * @uses load_theme_textdomain() For translation/localization support.
 * @uses add_editor_style() To add a Visual Editor stylesheet.
 * @uses add_theme_support() To add support for post thumbnails, automatic feed links,
 *    custom background, and post formats.
 * @uses register_nav_menu() To add support for navigation menus.
 * @uses set_post_thumbnail_size() To set a custom post thumbnail size.
 *
 * @since Kleo Framework 1.0
 */
function kleo_setup() {

	/*
	 * Makes theme available for translation.
	 * Translations can be added to the /languages/ directory.
	 */
	load_theme_textdomain( 'buddyapp', get_template_directory() . '/languages' );

	/* This theme styles the visual editor with editor-style.css to match the theme style. */
	add_editor_style();

	/* Adds RSS feed links to <head> for posts and comments. */
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Enable support for Post Formats.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'image',
		'gallery',
		'status',
		'quote',
		'video'
	) );

	/* This theme uses wp_nav_menu() in two locations. */
	register_nav_menu( 'primary', esc_html__( 'Main Menu (Side)', 'buddyapp' ) );
	register_nav_menu( 'top-left', esc_html__( 'Top Left Header Menu', 'buddyapp' ) );
	register_nav_menu( 'top-right', esc_html__( 'Top Right Header Menu', 'buddyapp' ) );


	/* This theme uses a custom image size for featured images, displayed on "standard" posts. */
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 672, 9999 ); // Unlimited height, soft crop
	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
	) );

	/* Specific framework functionality */
	add_theme_support( 'kleo-sidebar-generator' );
	add_theme_support( 'kleo-menu-custom' );
	add_theme_support( 'kleo-menu-items' );

	/* Third-party plugins */
	add_theme_support( 'bbpress' );

	add_theme_support( 'woocommerce' );
	/*Add gallery and lightbox support for woocomemrce */
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );

	add_theme_support( 'title-tag' );


}

add_action( 'after_setup_theme', 'kleo_setup' );


/***************************************************
 * :: Load Theme files
 ***************************************************/

add_action( 'after_setup_theme', 'kleo_theme_functions', 12 );

function kleo_theme_functions() {

	/* Fallback if BuddyApp core plugin is not installed */
	if ( ! function_exists( 'aq_resize' ) ) {
		function aq_resize( $url, $width = null, $height = null, $crop = null, $single = true, $upscale = false ) {
			return $url;
		}
	}

	// Menu structure
	require_once( KLEO_LIB_DIR . '/menu.php' );

	/* Custom menu */
	require_if_theme_supports( 'kleo-menu-custom', KLEO_LIB_DIR . '/menu-custom.php' );

	/* Custom menu items */
	require_if_theme_supports( 'kleo-menu-items', KLEO_LIB_DIR . '/menu-items.php' );

	/* Include admin customizations */
	if ( is_customize_preview() ) {
		require_once( KLEO_LIB_DIR . '/customizer/setup.php' );
	}

	//Meta Boxes
	if ( is_admin() ) {
		require_once( KLEO_LIB_DIR . '/metaboxes.php' );
	}

	//Dynamic CSS generation
	require_once( KLEO_LIB_DIR . '/dynamic-css/dynamic-css.php' );

	/* BuddyPress compatibility */
	if ( function_exists( 'bp_is_active' ) ) {
		require_once( KLEO_LIB_DIR . '/plugins/buddypress/buddypress.php' );
	}

	/* bbPress compatibility */
	if ( class_exists( 'bbPress' ) ) {
		require_once( KLEO_LIB_DIR . '/plugins/bbpress/bbpress.php' );
	}

	/* Woocommerce compatibility */
	if ( class_exists( 'WooCommerce' ) ) {
		require_once( KLEO_LIB_DIR . '/plugins/woocommerce.php' );
	}

	/* WPML compatibility */
	if ( function_exists( 'icl_get_languages' ) ) {
		require_once( KLEO_LIB_DIR . '/plugins/wpml.php' );
	}

	/* Visual composer compatibility */
	if ( function_exists( 'vc_set_as_theme' ) ) {
		require_once( KLEO_LIB_DIR . '/plugins/visual-composer.php' );
	}

	/* Cleverness TodoList compatibility */
	if ( class_exists( 'CTDL_Widget' ) ) {
		require_once( KLEO_LIB_DIR . '/plugins/ctdl.php' );
	}

	/* Easy Knowledge Base compatibility */
	if ( function_exists( 'sq_kb_setup_post_type' ) ) {
		require_once( KLEO_LIB_DIR . '/plugins/easy-kb/easy-kb.php' );
	}

	// menu-items-visibility-control plugin compatibility
	if ( class_exists( 'Boom_Walker_Nav_Menu_Edit' ) ) {
		require_once( KLEO_LIB_DIR . '/plugins/menu-items-visibility-control.php' );
	}

}


/***************************************************
 * :: Load Theme specific functions
 ***************************************************/

require_once( trailingslashit( KLEO_LIB_DIR ) . 'theme-functions.php' );


/***************************************************
 * :: Load Theme Panel
 ***************************************************/

if ( is_admin() ) {
	require_once( trailingslashit( KLEO_LIB_DIR ) . 'theme-panel/init.php' );
}


/***************************************************
 * :: 1 Click Install
 ***************************************************/
if ( is_admin() ) {
	require_once( trailingslashit( KLEO_LIB_DIR ) . '/importer/import.php' );
}


/***************************************************
 * :: Load components
 ***************************************************/

$kleo_components = array(
	'base.php',
	'page-title.php',
	'extras.php',
);

$kleo_components = apply_filters( 'kleo_components', $kleo_components );

foreach ( $kleo_components as $component ) {
	$file_path = trailingslashit( KLEO_LIB_DIR ) . 'components/' . $component;
	include_once $file_path;
}


/***************************************************
 * :: Load modules
 ***************************************************/

$kleo_modules = array(
	'facebook-login.php'
);

$kleo_modules = apply_filters( 'kleo_modules', $kleo_modules );

foreach ( $kleo_modules as $module ) {
	$file_path = trailingslashit( KLEO_LIB_DIR ) . 'modules/' . $module;
	include_once $file_path;
}


/***************************************************
 * :: Widgets
 ***************************************************/

if ( ! function_exists( 'kleo_widgets_init' ) ) {
	/**
	 * Registers our main widget area and the front page widget areas.
	 *
	 * @since Kleo 1.0
	 */
	function kleo_widgets_init() {
		register_sidebar( array(
			'name'          => esc_html__( 'Main Sidebar', 'buddyapp' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Main Sidebar', 'buddyapp' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );

		register_sidebar( array(
			'name'          => esc_html__( 'Side menu Area', 'buddyapp' ),
			'id'            => 'side',
			'description'   => esc_html__( 'Side Menu Area', 'buddyapp' ),
			'before_widget' => '<div id="%1$s" class="menu-section widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<p class="menu-section-header"><span>',
			'after_title'   => '</span></p>',
		) );

		register_sidebar( array(
			'name'          => 'Footer column 1',
			'id'            => 'footer-1',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );

		register_sidebar( array(
			'name'          => 'Footer column 2',
			'id'            => 'footer-2',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );

		register_sidebar( array(
			'name'          => 'Footer column 3',
			'id'            => 'footer-3',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );

		register_sidebar( array(
			'name'          => 'Footer column 4',
			'id'            => 'footer-4',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );

	}
}
add_action( 'widgets_init', 'kleo_widgets_init' );


/***************************************************
 * :: Scripts/Styles load
 ***************************************************/

add_action( 'wp_enqueue_scripts', 'kleo_frontend_files' );
if ( ! function_exists( 'kleo_frontend_files' ) ) :
	// Register some javascript files
	function kleo_frontend_files() {

		$min = '';
		if ( sq_option( 'dev_mode', false ) == false ) {
			$min = '.min';
		}
		//head scripts
		wp_register_script( 'modernizr', get_template_directory_uri() . '/assets/js/modernizr.custom.92164' . $min . '.js', array(), KLEO_THEME_VERSION, false );

		/* Footer scripts */
		wp_register_script( 'kleo-plugins', get_template_directory_uri() . '/assets/js/plugins' . $min . '.js', array( 'jquery' ), KLEO_THEME_VERSION, true );
		wp_register_script( 'kleo-app', get_template_directory_uri() . '/assets/js/functions' . $min . '.js', array(
			'jquery',
			'kleo-plugins'
		), KLEO_THEME_VERSION, true );

		//enqueue them
		wp_enqueue_script( 'modernizr' );
		wp_enqueue_script( 'kleo-plugins' );

		wp_enqueue_script( 'kleo-app' );

		$obj_array = array(
			'ajaxurl'        => admin_url( 'admin-ajax.php' ),
			'loadingMessage' => '<i class="icon-refresh animate-spin"></i> ' . esc_html__( 'Sending info, please wait...', 'buddyapp' ),
			'errorMessage'   => esc_html__( 'Sorry, an error occurred. Try again later.', 'buddyapp' ),
			'loginUrl'       => site_url( 'wp-login.php', 'login_post' ),
		);
		$obj_array = apply_filters( 'kleo_localize_app', $obj_array );

		wp_localize_script( 'kleo-app', 'KLEO', $obj_array );

		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

		// Register the styles
		wp_register_style( 'bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.min.css', array(), KLEO_THEME_VERSION, 'all' );
		wp_register_style( 'buddyapp', get_template_directory_uri() . '/assets/less/theme' . $min . '.css', array(), KLEO_THEME_VERSION, 'all' );
		wp_register_style( 'kleo-font-icons', sq_get_fonts_path(), array(), KLEO_THEME_VERSION, 'all' );
		wp_register_style( 'kleo-animate', get_template_directory_uri() . '/assets/css/animate.css', array(), KLEO_THEME_VERSION, 'all' );
		wp_register_style( 'magnific-popup', get_template_directory_uri() . '/assets/css/magnific-popup.css', array(), KLEO_THEME_VERSION, 'all' );
		wp_register_style( 'outdatedbrowser', get_template_directory_uri() . '/assets/js/3rd-plugins/outdatedbrowser/outdatedbrowser.min.css', array(), KLEO_THEME_VERSION, 'all' );

		wp_register_style( 'kleo-style', CHILD_THEME_URI . '/style.css', array(), KLEO_THEME_VERSION, 'all' );
		wp_register_style( 'kleo-rtl', get_template_directory_uri() . '/rtl.css', array(), KLEO_THEME_VERSION, 'all' );

		//enqueue required styles
		wp_enqueue_style( 'bootstrap' );
		wp_enqueue_style( 'buddyapp' );
		wp_enqueue_style( 'kleo-font-icons' );
		wp_enqueue_style( 'kleo-animate' );
		wp_enqueue_style( 'magnific-popup' );
		wp_enqueue_style( 'outdatedbrowser' );

	} // end kleo_frontend_files()
endif;


function sq_get_fonts_path() {
	$fonts_path = get_template_directory_uri() . '/assets/fonts/style.css';
	if ( is_child_theme() && file_exists( CHILD_THEME_DIR . '/assets/fonts/style.css' ) ) {
		$fonts_path = get_stylesheet_directory_uri() . '/assets/fonts/style.css';
	}

	return $fonts_path;
}


add_action( 'wp_enqueue_scripts', 'kleo_load_files_plugin_compat', 1000 );

function kleo_load_files_plugin_compat() {
	//enqueue child theme style only if activated
	if ( is_child_theme() ) {
		if ( is_rtl() ) {
			wp_enqueue_style( 'kleo-rtl' );
		}
		wp_enqueue_style( 'kleo-style' );
	}


} // kleo_load_css_files_plugin_compat()


/***************************************************
 * :: ADMIN CSS
 ***************************************************/
function kleo_admin_styles() {
	wp_register_style( "kleo-admin", KLEO_LIB_URI . "/assets/admin-custom.css", false, "1.0", "all" );
	wp_enqueue_style( 'kleo-admin' );
}

add_action( 'admin_enqueue_scripts', 'kleo_admin_styles' );


/***************************************************
 * :: Customize wp-login.php
 ***************************************************/
function custom_login_css() {
	$logo_side  = Kleo::get_config( 'logo_side' );
	$logo_image = sq_option( $logo_side, Kleo::get_config( $logo_side . '_default' ), true );

	if ( sq_option( 'sidemenu_header_bg' ) ) {
		$sidemenu_color = sq_option( 'sidemenu_header_bg', false, true );
	} else {
		$sidemenu_color = sq_option( 'sidemenu_style_background_color', '#121324', true );
	}

	echo "\n<style>";

	echo '.login h1 a { background-image: url("' . $logo_image . '") !important;background-size: contain !important;height: auto!important;width:180px !important;}';
	echo '.login {background-color: ' . $sidemenu_color . '; padding: 20px 0 0;}';
	echo '#login {padding: 20px 0 0;}';
	echo '.login #nav a, .login #backtoblog a {color:' . sq_option( 'sidemenu_style_link_color', '#ffffff' ) . '!important;text-shadow:none;}';

	echo "</style>\n";
}

add_action( 'login_enqueue_scripts', 'custom_login_css' );

function kleo_new_wp_login_url() {
	return home_url();
}

add_filter( 'login_headerurl', 'kleo_new_wp_login_url' );

function kleo_new_wp_login_title() {
	return get_option( 'blogname' );
}

add_filter( 'login_headertext', 'kleo_new_wp_login_title' );


if ( ! function_exists( '_wp_render_title_tag' ) ) {
	function kleo_slug_render_title() {
		?>
        <title><?php wp_title( '|', true, 'right' ); ?></title>
		<?php
	}

	add_action( 'wp_head', 'kleo_slug_render_title' );
}


if ( ! function_exists( 'kleo_wp_title' ) ):
	/**
	 * Creates a nicely formatted and more specific title element text
	 * for output in head of document, based on current view.
	 *
	 * @param string $title Default title text for current view.
	 * @param string $sep Optional separator.
	 *
	 * @return string Filtered title.
	 * @since Kleo Framework 1.0
	 *
	 */
	function kleo_wp_title( $title, $sep ) {
		global $paged, $page;

		if ( is_feed() ) {
			return $title;
		}
		// Add the site name.
		$title .= get_bloginfo( 'name' );

		// Add the site description for the home/front page.
		$site_description = get_bloginfo( 'description', 'display' );
		if ( $site_description && ( is_home() || is_front_page() ) ) {
			$title = "$title $sep $site_description";
		}
		// Add a page number if necessary.
		if ( $paged >= 2 || $page >= 2 ) {
			$title = "$title $sep " . sprintf( esc_html__( 'Page %s', 'buddyapp' ), max( $paged, $page ) );
		}

		return $title;
	}

	if ( ! function_exists( '_wp_render_title_tag' ) ) {
		add_filter( 'wp_title', 'kleo_wp_title', 10, 2 );
	}
endif;


if ( ! function_exists( 'kleo_the_attached_image' ) ) :
	/**
	 * Print the attached image with a link to the next attached image.
	 *
	 * @return void
	 * @since Kleo 1.0
	 *
	 */
	function kleo_the_attached_image() {
		$post = get_post();
		/**
		 * Filter the default attachment size.
		 *
		 * @param array $dimensions {
		 *     An array of height and width dimensions.
		 *
		 * @type int $height Height of the image in pixels. Default 810.
		 * @type int $width Width of the image in pixels. Default 810.
		 * }
		 * @since Kleo 1.0
		 *
		 */
		$attachment_size     = apply_filters( 'kleo_attachment_size', array( 810, 810 ) );
		$next_attachment_url = wp_get_attachment_url();

		/*
		 * Grab the IDs of all the image attachments in a gallery so we can get the URL
		 * of the next adjacent image in a gallery, or the first image (if we're
		 * looking at the last image in a gallery), or, in a gallery of one, just the
		 * link to that image file.
		 */
		$attachment_ids = get_posts( array(
			'post_parent'    => $post->post_parent,
			'fields'         => 'ids',
			'numberposts'    => - 1,
			'post_status'    => 'inherit',
			'post_type'      => 'attachment',
			'post_mime_type' => 'image',
			'order'          => 'ASC',
			'orderby'        => 'menu_order ID',
		) );

		// If there is more than 1 attachment in a gallery...
		if ( count( $attachment_ids ) > 1 ) {
			foreach ( $attachment_ids as $attachment_id ) {
				if ( $attachment_id == $post->ID ) {
					$next_id = current( $attachment_ids );
					break;
				}
			}

			// get the URL of the next image attachment...
			if ( $next_id ) {
				$next_attachment_url = get_attachment_link( $next_id );
			} // or get the URL of the first image attachment.
			else {
				$next_attachment_url = get_attachment_link( array_shift( $attachment_ids ) );
			}
		}

		printf( '<a href="%1$s" rel="attachment">%2$s</a>',
			esc_url( $next_attachment_url ),
			wp_get_attachment_image( $post->ID, $attachment_size )
		);
	}
endif;


/***************************************************
 * :: Modal Ajax login && Modal Lost Password
 ***************************************************/


add_filter( 'kleo_theme_settings', 'kleo_login_settings' );

function kleo_login_settings( $kleo ) {
	//
	// Settings Sections
	//

	$kleo['sec']['kleo_section_login'] = array(
		'title'    => esc_html__( 'Login redirect', 'buddyapp' ),
		'priority' => 16
	);

	$kleo['set'][] = array(
		'id'          => 'login_redirect',
		'title'       => esc_html__( 'Login page redirect', 'buddyapp' ),
		'type'        => 'select',
		'default'     => 'default',
		'choices'     => array( 'default' => 'Default', 'reload' => 'Reload', 'custom' => 'Custom link' ),
		'section'     => 'kleo_section_login',
		'description' => esc_html__( 'Default: WordPress default behaviour. Reload: will reload current page.', 'buddyapp' ),
	);

	$kleo['set'][] = array(
		'id'          => 'login_redirect_custom',
		'title'       => esc_html__( 'Custom link redirect', 'buddyapp' ),
		'type'        => 'text',
		'default'     => '',
		'section'     => 'kleo_section_login',
		'description' => esc_html__( 'Set a link like http://yoursite.com/homepage for users to get redirected on login.', 'buddyapp' ) . '<br>' .
		                 esc_html__( 'For more complex redirect logic please set Login redirect to Default WordPress and use Peter\'s redirect plugin or similar.', 'buddyapp' ),
		'condition'   => array( 'login_redirect', 'custom' )
	);

	return $kleo;

}

add_action( 'wp_footer', 'kleo_load_popups', 12 );

function kleo_load_popups() {
	get_template_part( 'page-parts/general-popups' );
}


/***************************************************
 * :: Custom redirect from Theme options - Login redirect
 ***************************************************/

if ( sq_option( 'login_redirect', 'default' ) == 'custom' && sq_option( 'login_redirect_custom', '' ) != '' ) {
	add_filter( 'login_redirect', 'kleo_custom_redirect', 12, 3 );
}

/**
 * Redirect user after successful login.
 *
 * @param string $redirect_to URL to redirect to.
 * @param string $requested_redirect_to URL for redirect
 * @param object $user Logged user's data.
 *
 * @return string
 */
function kleo_custom_redirect( $redirect_to, $requested_redirect_to, $user ) {
	if ( ( $requested_redirect_to == '' || $requested_redirect_to == home_url() ) && ! is_wp_error( $user ) ) {
		$redirect_to = sq_option( 'login_redirect_custom', '' );
		$redirect_to = str_replace( '##member_name##', $user->user_login, $redirect_to );
	}

	return $redirect_to;
}

// -----------------------------------------------------------------------------


/***************************************************
 * :: Render the footer columns
 ***************************************************/

function add_footer_widgets_columns() {

	if ( ! is_active_sidebar( 'footer-1' ) && ! is_active_sidebar( 'footer-2' ) && ! is_active_sidebar( 'footer-3' ) && ! is_active_sidebar( 'footer-4' ) ) {
		return;
	}

	?>
    <div id="footer" class="footer-color border-top">
        <div class="container-full">
            <div class="template-page tpl-no">
                <div class="wrap-content">
                    <div class="row">
                        <div class="col-sm-3">
                            <div id="footer-sidebar-1" class="footer-sidebar widget-area" role="complementary">
								<?php
								if ( ! function_exists( 'dynamic_sidebar' ) || ! dynamic_sidebar( 'footer-1' ) ):
								endif;
								?>
                            </div>
                        </div>
                        <div class="col-sm-3">
                            <div id="footer-sidebar-2" class="footer-sidebar widget-area" role="complementary">
								<?php
								if ( ! function_exists( 'dynamic_sidebar' ) || ! dynamic_sidebar( 'footer-2' ) ):
								endif;
								?>
                            </div>
                        </div>
                        <div class="col-sm-3">
                            <div id="footer-sidebar-3" class="footer-sidebar widget-area" role="complementary">
								<?php
								if ( ! function_exists( 'dynamic_sidebar' ) || ! dynamic_sidebar( 'footer-3' ) ):
								endif;
								?>
                            </div>
                        </div>
                        <div class="col-sm-3">
                            <div id="footer-sidebar-4" class="footer-sidebar widget-area" role="complementary">
								<?php
								if ( ! function_exists( 'dynamic_sidebar' ) || ! dynamic_sidebar( 'footer-4' ) ):
								endif;
								?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div><!-- #footer -->

	<?php
}

add_action( 'kleo_after_content', 'add_footer_widgets_columns', 20 );
