<?php
/**
 * Plugin logic
 *
 * @link       http://seventhqueen.com
 * @since      1.0.0
 *
 * @package    Restrict_My_Site
 */

if ( ! class_exists( 'Kleo' ) ) {
	return;
}

/***************************************************
 * :: Theme settings
 ***************************************************/


add_filter( 'kleo_theme_settings', 'kleo_private_settings' );

function kleo_private_settings( $kleo ) {
	//
	// Settings Sections
	//

	$kleo['sec']['kleo_section_private'] = array(
		'title'    => __( 'Private site', 'buddyapp' ),
		'priority' => 16
	);

	$kleo['set'][] = array(
		'id'          => 'restricted_site',
		'title'       => __( 'Make my site private', 'buddyapp' ),
		'type'        => 'select',
		'default'     => 'no',
		'choices'     => array( 'no' => 'No', 'yes' => 'Yes' ),
		'section'     => 'kleo_section_private',
		'description' => __( 'Restrict all pages from not logged in users.', 'buddyapp' ),
	);


	$pages_array = array( '' => 'None' );
	$pages       = get_pages();
	foreach ( $pages as $page ) {
		$pages_array[ $page->ID ] = $page->post_title;
	}

	$kleo['set'][] = array(
		'id'          => 'restrict_login_page',
		'title'       => __( 'Login page', 'buddyapp' ),
		'type'        => 'select',
		'default'     => '',
		'choices'     => $pages_array,
		'section'     => 'kleo_section_private',
		'description' => __( 'Select a page to redirect restricted users.', 'buddyapp' ),
		'condition'   => array( 'restricted_site', 'yes' )
	);
	$kleo['set'][] = array(
		'id'          => 'login_custom_page',
		'title'       => __( 'Change wordPress default login too', 'buddyapp' ),
		'type'        => 'switch',
		'default'     => 0,
		'section'     => 'kleo_section_private',
		'description' => __( 'Also Replace default wordpress login url with the above login page', 'buddyapp' ),
		'condition'   => array( 'restricted_site', 'yes' )

	);

	$kleo['set'][] = array(
		'id'          => 'restricted_site_excludes',
		'title'       => __( 'Pages exceptions', 'buddyapp' ),
		'type'        => 'multi-select',
		'default'     => '',
		'choices'     => $pages_array,
		'section'     => 'kleo_section_private',
		'description' => __( 'Page restrictions exceptions. Select pages to make public', 'buddyapp' ),
		'condition'   => array( 'restricted_site', 'yes' )
	);

	$kleo['set'][] = array(
		'id'          => 'restricted_blog',
		'title'       => __( 'Restrict Blog page and articles', 'buddyapp' ),
		'type'        => 'switch',
		'default'     => '1',
		'section'     => 'kleo_section_private',
		'description' => __( 'When site is private, restrict Blog and articles for guest users.', 'buddyapp' ),
		'condition'   => array( 'restricted_site', 'yes' )
	);

	$kleo['set'][] = array(
		'id'          => 'restricted_bbpress',
		'title'       => __( 'Restrict bbPress pages', 'buddyapp' ),
		'type'        => 'switch',
		'default'     => '1',
		'section'     => 'kleo_section_private',
		'description' => __( 'When site is private, restrict bbPress pages for guest users.', 'buddyapp' ),
		'condition'   => array( 'restricted_site', 'yes' )

	);

	return $kleo;

}

/**
 * Redirect restricted pages to login
 */
function kleo_restrict_site() {

	if ( is_user_logged_in() || sq_option( 'restricted_site', 'no' ) != 'yes' ) {
		return;
	}

	if ( function_exists( 'bp_is_active' ) && ( bp_is_activation_page() || bp_is_register_page() ) ) {
		return;
	}

	// Allow blog
	if ( sq_option( 'restricted_blog', 1 ) == 0 && ( is_singular('post') || is_home() ) ) {
		return;
	}

	// allow bbPress
	if ( function_exists( 'is_bbpress' ) ) {
		if ( sq_option( 'restricted_bbpress', 1 ) == 0 && is_bbpress() && ! ( function_exists('bp_is_active') && bp_is_user() ) ) {
			return;
		}
	}


	$excluded = sq_option( 'restricted_site_excludes', '' );

	if ( ! empty( $excluded ) ) {
		$excluded  = (array) $excluded;
		$object_id = get_queried_object_id();

		if ( ! $object_id && function_exists( 'is_shop' ) && is_shop() ) {
			$object_id = wc_get_page_id( 'shop' );
		}

		if ( $object_id && in_array( $object_id, $excluded, false ) ) {
			return;
		}
	}

	/* Redirect to login */

	$redirect_page = home_url( '/wp-login.php' );

	//Custom redirect page
	if ( sq_option( 'restrict_login_page' ) ) {
		if ( get_permalink( sq_option( 'restrict_login_page' ) ) ) {
			$redirect_page = get_permalink( sq_option( 'restrict_login_page' ) );

			// If we are actually on the redirect page - bail out
			if ( is_page( sq_option( 'restrict_login_page' ) ) ) {
				return;
			}
		}
	}

	//Extra check so we don't enter a loop
	if ( kleo_full_url() === $redirect_page ) {
		return;
	}

	$redirect   = '?redirect_to=' . esc_url( kleo_full_url() );
	$return_url = esc_url( $redirect_page . $redirect );

	wp_redirect( $return_url );
	exit;

}

if ( ! is_admin() ) {
	add_action( 'template_redirect', 'kleo_restrict_site' );
}


/***************************************************
 * :: Custom Login Page from Theme options - Login Redirect
 *
 ***************************************************/

if ( ! function_exists( 'rms_custom_login_page' ) ) {
	function rms_custom_login_page( $login_url, $redirect ) {

		if ( sq_option( 'login_custom_page', 0 ) == 1 ) {
			$login_page = sq_option( 'restrict_login_page' );

			if ( $login_page && get_post( $login_page ) ) {

				$slug = get_post( $login_page )->post_name;

				return str_replace( "wp-login.php", $slug, $login_url );
			}
		}

		return $login_url;
	}

	add_filter( 'login_url', 'rms_custom_login_page', 999, 2 );
}


/* BuddyPress search restriction */

add_filter( 'bp_core_get_users', 'rms_bp_members_filter' );
function rms_bp_members_filter( $result ) {
	if ( ! is_user_logged_in() && sq_option( 'restricted_site', 'no' ) === 'yes' ) {
		return [ 'users' => [], 'total' => 0 ];
	}

	return $result;
}